@@ -372,7 +372,7 @@ def mass_to_name(masses: np.ndarray) -> np.ndarray:
     Return:
         The element name array.
     """
-    names = list()
+    names = []
     for mass in masses:
         for item in MM_of_Elements.items():
             if math.isclose(mass, item[1], abs_tol=0.1):
@@ -437,8 +437,8 @@ def res_dict_from_select_dict(u: Universe, select_dict: Dict[str, str]) -> Dict[
     return:
         A dictionary of resnames.
     """
-    saved_select = list()
-    res_dict = dict()
+    saved_select = []
+    res_dict = {}
     for key, val in select_dict.items():
         res_select = "same resid as (" + val + ")"
         res_group = u.select_atoms(res_select)
@@ -465,7 +465,7 @@ def res_dict_from_datafile(filename: str) -> Dict[str, str]:
     return:
         A dictionary of resnames.
     """
-    res_dict = dict()
+    res_dict = {}
     with open(filename, "r") as f:
         lines = f.readlines()
         if lines[0] == "Generated by pymatgen.io.lammps.data.LammpsData\n" and lines[1].startswith("#"):
@@ -503,7 +503,7 @@ def res_dict_from_lammpsdata(lammps_data: CombinedData) -> Dict[str, str]:
     """
     assert isinstance(lammps_data, CombinedData)
     idx = 1
-    res_dict = dict()
+    res_dict = {}
 
     if hasattr(lammps_data, "frags"):
         for name, num, frag in zip(lammps_data.names, lammps_data.nums, lammps_data.frags):
@@ -538,7 +538,7 @@ def select_dict_from_resname(u: Universe) -> Dict[str, str]:
     return:
         A dictionary of atom species.
     """
-    select_dict: Dict[str, str] = dict()
+    select_dict: Dict[str, str] = {}
     resnames = np.unique(u.residues.resnames)
     for resname in resnames:
         if resname == "":
@@ -673,10 +673,10 @@ def ff_parser(ff_dir: str, xyz_dir: str) -> str:
         lines_org = f.read()
         lines = lines_org.split("\n\n")
         atoms = "\n".join(lines[4].split("\n", 4)[4].split("\n")[:-1])
-        dfs = dict()
+        dfs = {}
         dfs["atoms"] = pd.read_csv(
             StringIO(atoms),
-            names=SECTION_SORTER.get("atoms", dict()).get("in_header"),
+            names=SECTION_SORTER.get("atoms", {}).get("in_header"),
             delim_whitespace=True,
             usecols=[0, 4, 5, 6],
         )
@@ -692,9 +692,9 @@ def ff_parser(ff_dir: str, xyz_dir: str) -> str:
             "atom3": dict(types),
             "atom4": dict(types),
         }
-        counts = dict()
+        counts = {}
         counts["atoms"] = len(dfs["atoms"].index)
-        mass_list = list()
+        mass_list = []
         for index, row in dfs["atoms"].iterrows():
             mass_list.append(MM_of_Elements.get(re.split(r"(\d+)", row["atom"])[0]))
         mass_df = pd.DataFrame(mass_list)
@@ -747,7 +747,7 @@ def ff_parser(ff_dir: str, xyz_dir: str) -> str:
                 topo.append(topo_string)
                 counts[section] = len(dfs[section].index)
         max_stats = len(str(max(list(counts.values()))))
-        stats_template = "{:>%d}  {}" % max_stats
+        stats_template = "{:>" + str(max_stats) + "}  {}"
         count_lines = [stats_template.format(v, k) for k, v in counts.items()]
         type_lines = [stats_template.format(v, k[:-1] + " types") for k, v in counts.items()]
         stats = "\n".join(count_lines + [""] + type_lines)
@@ -816,7 +816,7 @@ def concentration_matcher(
         The list is followed by a float of the approximate length of one side of the box in Å.
 
     """
-    n_solvent = list()
+    n_solvent = []
     n = len(solv_ratio)
     if n != len(solvents):
         raise ValueError("solvents and solv_ratio must be the same length!")
@@ -830,7 +830,7 @@ def concentration_matcher(
             salt_molar_volume = MOLAR_VOLUME.get(salt.lower(), 0)
         else:
             if not os.path.exists(salt):
-                print("\nError: Input file '{}' not found.\n".format(salt))
+                print(f"\nError: Input file '{salt}' not found.\n")
                 sys.exit(1)
             name = os.path.splitext(os.path.split(salt)[-1])[0]
             ext = os.path.splitext(os.path.split(salt)[-1])[1]
@@ -841,8 +841,8 @@ def concentration_matcher(
     else:
         raise ValueError("Invalid salt type! Salt must be a number, string, or Molecule.")
 
-    solv_mass = list()
-    solv_density = list()
+    solv_mass = []
+    solv_density = []
     for solv in solvents:
         if isinstance(solv, dict):
             solv_mass.append(solv.get("mass"))
@@ -900,13 +900,13 @@ def sdf_to_pdb(
         title = "cid_"
     else:
         title = ""
-    pdb_atoms: List[Dict[str, Any]] = list()
+    pdb_atoms: List[Dict[str, Any]] = []
     # create pdb list of dictionaries
     atoms = 0
     bonds = 0
-    atom1s = list()
-    atom2s = list()
-    orders = list()
+    atom1s = []
+    atom2s = []
+    orders = []
     for i, line in enumerate(sdf):
         if i == 0:
             title += line.strip() + " "
@@ -956,7 +956,7 @@ def sdf_to_pdb(
     # write pdb file
     with open(pdb_file, "wt") as outp:
         if write_title:
-            outp.write("TITLE     {:70s}\n".format(title))
+            outp.write(f"TITLE     {title:70s}\n")
         if version:
             outp.write("REMARK   4      COMPLIES WITH FORMAT V. 3.3, 21-NOV-2012\n")
         if credit:
@@ -967,7 +967,7 @@ def sdf_to_pdb(
                 line_dict["name"] = " " + line_dict["name"]
             # format pdb
             formatted_line = (
-                "{:<6s}{:>5d} {:^4s}{:1s}{:>3s} {:1s}{:>4.4}{:1s}   "
+                "{:<6s}{:>5d} {:^4s}{:1s}{:>3s} {:1s}{:>4.4}{:1s}   "  # pylint: disable=C0209
                 "{:>8.3f}{:>8.3f}{:>8.3f}{:>6.2f}{:>6.2f}      "
                 "{:<4s}{:>2s}{:<2s}"
             ).format(
@@ -1004,7 +1004,7 @@ def sdf_to_pdb(
         for i in range(1, len(bond_lines)):
             bond_lines[i][1:] = sorted(bond_lines[i][1:])
         for i in range(1, len(bond_lines)):
-            outp.write("CONECT" + "".join("{:>5d}".format(num) for num in bond_lines[i]) + "\n")
+            outp.write("CONECT" + "".join(f"{num:>5d}" for num in bond_lines[i]) + "\n")
         outp.write("END\n")  # final 'END'
 
 
